@@ -1,13 +1,14 @@
 package Catmandu::Fix::pica_map;
 
 # ABSTRACT: copy mab values of one field to a new field
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use Catmandu::Sane;
 use Carp qw(confess);
 use Moo;
 
 use Catmandu::Fix::Has;
+use Catmandu::PICA;
 
 has pica_path => ( fix_arg => 1 );
 has path      => ( fix_arg => 1 );
@@ -23,24 +24,8 @@ sub emit {
     my $join_char  = $fixer->emit_string( $self->join // '' );
     my $pica_path  = $self->pica_path;
 
-    my $field_regex;
-    my ( $field, $occurence, $subfield_regex, $from, $to );
-
-    if ( $pica_path
-        =~ /(\d{3}\S)(\[(\d{2})\])?([_A-Za-z0-9]+)?(\/(\d+)(-(\d+))?)?/ )
-    {
-        $field          = $1;
-        $occurence      = $3;
-        $subfield_regex = defined $4 ? "[$4]" : "[_A-Za-z0-9]";
-        $from           = $6;
-        $to             = $8;
-    }
-    else {
-        confess "invalid pica path";
-    }
-
-    $field_regex = $field;
-    $field_regex =~ s/\*/./g;
+    my $parsed_path = Catmandu::PICA::parse_pica_path($pica_path) or confess "invalid pica path";
+    my ( $field_regex, $occurrence_regex, $subfield_regex, $from, $to ) = @$parsed_path;
 
     my $var  = $fixer->var;
     my $vals = $fixer->generate_var;
@@ -55,6 +40,10 @@ sub emit {
 
             $perl .= "next if ${var}->[0] !~ /${field_regex}/;";
 
+            if (defined $occurrence_regex) {
+                $perl .= "next if (!defined ${var}->[1] || ${var}->[1] !~ /${occurrence_regex}/);";
+            }
+
             if ( $self->value ) {
                 $perl .= $fixer->emit_declare_vars( $v,
                     $fixer->emit_string( $self->value ) );
@@ -122,7 +111,7 @@ Catmandu::Fix::pica_map - copy mab values of one field to a new field
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -141,6 +130,8 @@ version 0.09
     # Copy from field 028A with ocurrance subfields a and d to dc.contributor hash joining them by ' '
     pica_map('028B[01]ad','dcterms.ccontributor', -join => ' ');
 
+=back
+
 =head1 AUTHOR
 
 Johann Rolschewski <rolschewski@gmail.com>
