@@ -1,6 +1,22 @@
 package Catmandu::PICA;
 #ABSTRACT: Catmandu modules for working with PICA+ data.
-our $VERSION = '0.09'; #VERSION
+our $VERSION = '0.10'; #VERSION
+
+sub parse_pica_path {
+    return if $_[0] !~ /(\d{3}\S)(\[([0-9*]{2})\])?([_A-Za-z0-9]+)?(\/(\d+)(-(\d+))?)?/;
+    my @path = (
+        $1, # field
+        $3, # occurrence
+        defined $4 ? "[$4]" : "[_A-Za-z0-9]", # subfield_regex
+    );
+
+    push(@path, $6, $8) if defined $5; # from, to
+
+    $path[0] =~ s/\*/./g;                     # field => field_regex
+    $path[1] =~ s/\*/./g if defined $path[1]; # occurrence => occurrence_regex
+
+    return \@path;
+}
 
 
 1; # End of Catmandu::PICA
@@ -17,7 +33,7 @@ Catmandu::PICA - Catmandu modules for working with PICA+ data.
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -59,6 +75,34 @@ The following modules may be renamed or removed in a future release.
 
 =back
 
+=head1 FUNCTIONS
+
+=head2 parse_pica_path( $path )
+
+Parses a PICA path expression. On success returns a list reference with:
+
+=over
+
+=item
+
+regex string to match fields against (must be compiled with C<qr{...}> or C</.../>)
+
+=item
+
+regex string to match occurrences against (must be compiled)
+
+=item
+
+regex string to match subfields against (must be compiled)
+
+=item
+
+substring start position
+
+=item
+
+substring end position
+
 =head1 CONTRIBUTORS
 
 Johann Rolschewski, <rolschewski@gmail.com>
